# pulp_ostree_client

PulpOstreeClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 2.0.0a1
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_ostree_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_ostree_client-2.0.0a1.gem
```

(for development, run `gem install --dev ./pulp_ostree_client-2.0.0a1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_ostree_client', '~> 2.0.0a1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_ostree_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_ostree_client'

# Setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpOstreeClient::ContentCommitsApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List ostree commits
  result = api_instance.list(opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentCommitsApi->list: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpOstreeClient::ContentCommitsApi* | [**list**](docs/ContentCommitsApi.md#list) | **GET** /pulp/api/v3/content/ostree/commits/ | List ostree commits
*PulpOstreeClient::ContentCommitsApi* | [**read**](docs/ContentCommitsApi.md#read) | **GET** {ostree_ostree_commit_href} | Inspect an ostree commit
*PulpOstreeClient::ContentConfigsApi* | [**list**](docs/ContentConfigsApi.md#list) | **GET** /pulp/api/v3/content/ostree/configs/ | List ostree configs
*PulpOstreeClient::ContentConfigsApi* | [**read**](docs/ContentConfigsApi.md#read) | **GET** {ostree_ostree_config_href} | Inspect an ostree config
*PulpOstreeClient::ContentObjectsApi* | [**list**](docs/ContentObjectsApi.md#list) | **GET** /pulp/api/v3/content/ostree/objects/ | List ostree objects
*PulpOstreeClient::ContentObjectsApi* | [**read**](docs/ContentObjectsApi.md#read) | **GET** {ostree_ostree_object_href} | Inspect an ostree object
*PulpOstreeClient::ContentRefsApi* | [**list**](docs/ContentRefsApi.md#list) | **GET** /pulp/api/v3/content/ostree/refs/ | List ostree refs
*PulpOstreeClient::ContentRefsApi* | [**read**](docs/ContentRefsApi.md#read) | **GET** {ostree_ostree_ref_href} | Inspect an ostree ref
*PulpOstreeClient::ContentSummariesApi* | [**list**](docs/ContentSummariesApi.md#list) | **GET** /pulp/api/v3/content/ostree/summaries/ | List ostree summarys
*PulpOstreeClient::ContentSummariesApi* | [**read**](docs/ContentSummariesApi.md#read) | **GET** {ostree_ostree_summary_href} | Inspect an ostree summary
*PulpOstreeClient::DistributionsOstreeApi* | [**create**](docs/DistributionsOstreeApi.md#create) | **POST** /pulp/api/v3/distributions/ostree/ostree/ | Create an ostree distribution
*PulpOstreeClient::DistributionsOstreeApi* | [**delete**](docs/DistributionsOstreeApi.md#delete) | **DELETE** {ostree_ostree_distribution_href} | Delete an ostree distribution
*PulpOstreeClient::DistributionsOstreeApi* | [**list**](docs/DistributionsOstreeApi.md#list) | **GET** /pulp/api/v3/distributions/ostree/ostree/ | List ostree distributions
*PulpOstreeClient::DistributionsOstreeApi* | [**partial_update**](docs/DistributionsOstreeApi.md#partial_update) | **PATCH** {ostree_ostree_distribution_href} | Update an ostree distribution
*PulpOstreeClient::DistributionsOstreeApi* | [**read**](docs/DistributionsOstreeApi.md#read) | **GET** {ostree_ostree_distribution_href} | Inspect an ostree distribution
*PulpOstreeClient::DistributionsOstreeApi* | [**update**](docs/DistributionsOstreeApi.md#update) | **PUT** {ostree_ostree_distribution_href} | Update an ostree distribution
*PulpOstreeClient::RemotesOstreeApi* | [**create**](docs/RemotesOstreeApi.md#create) | **POST** /pulp/api/v3/remotes/ostree/ostree/ | Create an ostree remote
*PulpOstreeClient::RemotesOstreeApi* | [**delete**](docs/RemotesOstreeApi.md#delete) | **DELETE** {ostree_ostree_remote_href} | Delete an ostree remote
*PulpOstreeClient::RemotesOstreeApi* | [**list**](docs/RemotesOstreeApi.md#list) | **GET** /pulp/api/v3/remotes/ostree/ostree/ | List ostree remotes
*PulpOstreeClient::RemotesOstreeApi* | [**partial_update**](docs/RemotesOstreeApi.md#partial_update) | **PATCH** {ostree_ostree_remote_href} | Update an ostree remote
*PulpOstreeClient::RemotesOstreeApi* | [**read**](docs/RemotesOstreeApi.md#read) | **GET** {ostree_ostree_remote_href} | Inspect an ostree remote
*PulpOstreeClient::RemotesOstreeApi* | [**update**](docs/RemotesOstreeApi.md#update) | **PUT** {ostree_ostree_remote_href} | Update an ostree remote
*PulpOstreeClient::RepositoriesOstreeApi* | [**create**](docs/RepositoriesOstreeApi.md#create) | **POST** /pulp/api/v3/repositories/ostree/ostree/ | Create an ostree repository
*PulpOstreeClient::RepositoriesOstreeApi* | [**delete**](docs/RepositoriesOstreeApi.md#delete) | **DELETE** {ostree_ostree_repository_href} | Delete an ostree repository
*PulpOstreeClient::RepositoriesOstreeApi* | [**import_commits**](docs/RepositoriesOstreeApi.md#import_commits) | **POST** {ostree_ostree_repository_href}import_commits/ | Import commits to a repository
*PulpOstreeClient::RepositoriesOstreeApi* | [**list**](docs/RepositoriesOstreeApi.md#list) | **GET** /pulp/api/v3/repositories/ostree/ostree/ | List ostree repositorys
*PulpOstreeClient::RepositoriesOstreeApi* | [**modify**](docs/RepositoriesOstreeApi.md#modify) | **POST** {ostree_ostree_repository_href}modify/ | Modify Repository Content
*PulpOstreeClient::RepositoriesOstreeApi* | [**partial_update**](docs/RepositoriesOstreeApi.md#partial_update) | **PATCH** {ostree_ostree_repository_href} | Update an ostree repository
*PulpOstreeClient::RepositoriesOstreeApi* | [**read**](docs/RepositoriesOstreeApi.md#read) | **GET** {ostree_ostree_repository_href} | Inspect an ostree repository
*PulpOstreeClient::RepositoriesOstreeApi* | [**sync**](docs/RepositoriesOstreeApi.md#sync) | **POST** {ostree_ostree_repository_href}sync/ | Sync from remote
*PulpOstreeClient::RepositoriesOstreeApi* | [**update**](docs/RepositoriesOstreeApi.md#update) | **PUT** {ostree_ostree_repository_href} | Update an ostree repository
*PulpOstreeClient::RepositoriesOstreeVersionsApi* | [**delete**](docs/RepositoriesOstreeVersionsApi.md#delete) | **DELETE** {ostree_ostree_repository_version_href} | Delete a repository version
*PulpOstreeClient::RepositoriesOstreeVersionsApi* | [**list**](docs/RepositoriesOstreeVersionsApi.md#list) | **GET** {ostree_ostree_repository_href}versions/ | List repository versions
*PulpOstreeClient::RepositoriesOstreeVersionsApi* | [**read**](docs/RepositoriesOstreeVersionsApi.md#read) | **GET** {ostree_ostree_repository_version_href} | Inspect a repository version
*PulpOstreeClient::RepositoriesOstreeVersionsApi* | [**repair**](docs/RepositoriesOstreeVersionsApi.md#repair) | **POST** {ostree_ostree_repository_version_href}repair/ | 


## Documentation for Models

 - [PulpOstreeClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpOstreeClient::ContentSummary](docs/ContentSummary.md)
 - [PulpOstreeClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpOstreeClient::OstreeOstreeCommitResponse](docs/OstreeOstreeCommitResponse.md)
 - [PulpOstreeClient::OstreeOstreeConfigResponse](docs/OstreeOstreeConfigResponse.md)
 - [PulpOstreeClient::OstreeOstreeDistribution](docs/OstreeOstreeDistribution.md)
 - [PulpOstreeClient::OstreeOstreeDistributionResponse](docs/OstreeOstreeDistributionResponse.md)
 - [PulpOstreeClient::OstreeOstreeObjectResponse](docs/OstreeOstreeObjectResponse.md)
 - [PulpOstreeClient::OstreeOstreeRefResponse](docs/OstreeOstreeRefResponse.md)
 - [PulpOstreeClient::OstreeOstreeRemote](docs/OstreeOstreeRemote.md)
 - [PulpOstreeClient::OstreeOstreeRemoteResponse](docs/OstreeOstreeRemoteResponse.md)
 - [PulpOstreeClient::OstreeOstreeRepository](docs/OstreeOstreeRepository.md)
 - [PulpOstreeClient::OstreeOstreeRepositoryResponse](docs/OstreeOstreeRepositoryResponse.md)
 - [PulpOstreeClient::OstreeOstreeSummaryResponse](docs/OstreeOstreeSummaryResponse.md)
 - [PulpOstreeClient::OstreeRepoImport](docs/OstreeRepoImport.md)
 - [PulpOstreeClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeCommitResponseList](docs/PaginatedostreeOstreeCommitResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeConfigResponseList](docs/PaginatedostreeOstreeConfigResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeDistributionResponseList](docs/PaginatedostreeOstreeDistributionResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeObjectResponseList](docs/PaginatedostreeOstreeObjectResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeRefResponseList](docs/PaginatedostreeOstreeRefResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeRemoteResponseList](docs/PaginatedostreeOstreeRemoteResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeRepositoryResponseList](docs/PaginatedostreeOstreeRepositoryResponseList.md)
 - [PulpOstreeClient::PaginatedostreeOstreeSummaryResponseList](docs/PaginatedostreeOstreeSummaryResponseList.md)
 - [PulpOstreeClient::PatchedostreeOstreeDistribution](docs/PatchedostreeOstreeDistribution.md)
 - [PulpOstreeClient::PatchedostreeOstreeRemote](docs/PatchedostreeOstreeRemote.md)
 - [PulpOstreeClient::PatchedostreeOstreeRepository](docs/PatchedostreeOstreeRepository.md)
 - [PulpOstreeClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpOstreeClient::RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [PulpOstreeClient::RepositorySyncURL](docs/RepositorySyncURL.md)
 - [PulpOstreeClient::RepositoryVersion](docs/RepositoryVersion.md)
 - [PulpOstreeClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

