# PulpOstreeClient::ContentObjectsApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](ContentObjectsApi.md#list) | **GET** /pulp/api/v3/content/ostree/objects/ | List ostree objects
[**read**](ContentObjectsApi.md#read) | **GET** {ostree_ostree_object_href} | Inspect an ostree object



## list

> PaginatedostreeOstreeObjectResponseList list(opts)

List ostree objects

A ViewSet class for OSTree objects (e.g., dirtree, dirmeta, file).

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::ContentObjectsApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List ostree objects
  result = api_instance.list(opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentObjectsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedostreeOstreeObjectResponseList**](PaginatedostreeOstreeObjectResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> OstreeOstreeObjectResponse read(ostree_ostree_object_href, opts)

Inspect an ostree object

A ViewSet class for OSTree objects (e.g., dirtree, dirmeta, file).

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::ContentObjectsApi.new
ostree_ostree_object_href = 'ostree_ostree_object_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an ostree object
  result = api_instance.read(ostree_ostree_object_href, opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentObjectsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_object_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**OstreeOstreeObjectResponse**](OstreeOstreeObjectResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

