# PulpOstreeClient::DistributionsOstreeApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsOstreeApi.md#create) | **POST** /pulp/api/v3/distributions/ostree/ostree/ | Create an ostree distribution
[**delete**](DistributionsOstreeApi.md#delete) | **DELETE** {ostree_ostree_distribution_href} | Delete an ostree distribution
[**list**](DistributionsOstreeApi.md#list) | **GET** /pulp/api/v3/distributions/ostree/ostree/ | List ostree distributions
[**partial_update**](DistributionsOstreeApi.md#partial_update) | **PATCH** {ostree_ostree_distribution_href} | Update an ostree distribution
[**read**](DistributionsOstreeApi.md#read) | **GET** {ostree_ostree_distribution_href} | Inspect an ostree distribution
[**update**](DistributionsOstreeApi.md#update) | **PUT** {ostree_ostree_distribution_href} | Update an ostree distribution



## create

> AsyncOperationResponse create(ostree_ostree_distribution)

Create an ostree distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::DistributionsOstreeApi.new
ostree_ostree_distribution = PulpOstreeClient::OstreeOstreeDistribution.new # OstreeOstreeDistribution | 

begin
  #Create an ostree distribution
  result = api_instance.create(ostree_ostree_distribution)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling DistributionsOstreeApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_distribution** | [**OstreeOstreeDistribution**](OstreeOstreeDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(ostree_ostree_distribution_href)

Delete an ostree distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::DistributionsOstreeApi.new
ostree_ostree_distribution_href = 'ostree_ostree_distribution_href_example' # String | 

begin
  #Delete an ostree distribution
  result = api_instance.delete(ostree_ostree_distribution_href)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling DistributionsOstreeApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_distribution_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedostreeOstreeDistributionResponseList list(opts)

List ostree distributions

A ViewSet class for OSTree distributions.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::DistributionsOstreeApi.new
opts = {
  base_path: 'base_path_example', # String | 
  base_path__contains: 'base_path__contains_example', # String | Filter results where base_path contains value
  base_path__icontains: 'base_path__icontains_example', # String | Filter results where base_path contains value
  base_path__in: ['base_path__in_example'], # Array<String> | Filter results where base_path is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List ostree distributions
  result = api_instance.list(opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling DistributionsOstreeApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**|  | [optional] 
 **base_path__contains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__icontains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__in** | [**Array&lt;String&gt;**](String.md)| Filter results where base_path is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedostreeOstreeDistributionResponseList**](PaginatedostreeOstreeDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(ostree_ostree_distribution_href, patchedostree_ostree_distribution)

Update an ostree distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::DistributionsOstreeApi.new
ostree_ostree_distribution_href = 'ostree_ostree_distribution_href_example' # String | 
patchedostree_ostree_distribution = PulpOstreeClient::PatchedostreeOstreeDistribution.new # PatchedostreeOstreeDistribution | 

begin
  #Update an ostree distribution
  result = api_instance.partial_update(ostree_ostree_distribution_href, patchedostree_ostree_distribution)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling DistributionsOstreeApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_distribution_href** | **String**|  | 
 **patchedostree_ostree_distribution** | [**PatchedostreeOstreeDistribution**](PatchedostreeOstreeDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> OstreeOstreeDistributionResponse read(ostree_ostree_distribution_href, opts)

Inspect an ostree distribution

A ViewSet class for OSTree distributions.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::DistributionsOstreeApi.new
ostree_ostree_distribution_href = 'ostree_ostree_distribution_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an ostree distribution
  result = api_instance.read(ostree_ostree_distribution_href, opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling DistributionsOstreeApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_distribution_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**OstreeOstreeDistributionResponse**](OstreeOstreeDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(ostree_ostree_distribution_href, ostree_ostree_distribution)

Update an ostree distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::DistributionsOstreeApi.new
ostree_ostree_distribution_href = 'ostree_ostree_distribution_href_example' # String | 
ostree_ostree_distribution = PulpOstreeClient::OstreeOstreeDistribution.new # OstreeOstreeDistribution | 

begin
  #Update an ostree distribution
  result = api_instance.update(ostree_ostree_distribution_href, ostree_ostree_distribution)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling DistributionsOstreeApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_distribution_href** | **String**|  | 
 **ostree_ostree_distribution** | [**OstreeOstreeDistribution**](OstreeOstreeDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

