# PulpOstreeClient::RemotesOstreeApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesOstreeApi.md#create) | **POST** /pulp/api/v3/remotes/ostree/ostree/ | Create an ostree remote
[**delete**](RemotesOstreeApi.md#delete) | **DELETE** {ostree_ostree_remote_href} | Delete an ostree remote
[**list**](RemotesOstreeApi.md#list) | **GET** /pulp/api/v3/remotes/ostree/ostree/ | List ostree remotes
[**partial_update**](RemotesOstreeApi.md#partial_update) | **PATCH** {ostree_ostree_remote_href} | Update an ostree remote
[**read**](RemotesOstreeApi.md#read) | **GET** {ostree_ostree_remote_href} | Inspect an ostree remote
[**update**](RemotesOstreeApi.md#update) | **PUT** {ostree_ostree_remote_href} | Update an ostree remote



## create

> OstreeOstreeRemoteResponse create(ostree_ostree_remote)

Create an ostree remote

A ViewSet class for OSTree remote repositories.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RemotesOstreeApi.new
ostree_ostree_remote = PulpOstreeClient::OstreeOstreeRemote.new # OstreeOstreeRemote | 

begin
  #Create an ostree remote
  result = api_instance.create(ostree_ostree_remote)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RemotesOstreeApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_remote** | [**OstreeOstreeRemote**](OstreeOstreeRemote.md)|  | 

### Return type

[**OstreeOstreeRemoteResponse**](OstreeOstreeRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(ostree_ostree_remote_href)

Delete an ostree remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RemotesOstreeApi.new
ostree_ostree_remote_href = 'ostree_ostree_remote_href_example' # String | 

begin
  #Delete an ostree remote
  result = api_instance.delete(ostree_ostree_remote_href)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RemotesOstreeApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_remote_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedostreeOstreeRemoteResponseList list(opts)

List ostree remotes

A ViewSet class for OSTree remote repositories.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RemotesOstreeApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_last_updated: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  pulp_last_updated__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than value
  pulp_last_updated__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than or equal to value
  pulp_last_updated__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than value
  pulp_last_updated__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than or equal to value
  pulp_last_updated__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_last_updated is between two comma separated values
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List ostree remotes
  result = api_instance.list(opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RemotesOstreeApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_last_updated** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **pulp_last_updated__gt** | **DateTime**| Filter results where pulp_last_updated is greater than value | [optional] 
 **pulp_last_updated__gte** | **DateTime**| Filter results where pulp_last_updated is greater than or equal to value | [optional] 
 **pulp_last_updated__lt** | **DateTime**| Filter results where pulp_last_updated is less than value | [optional] 
 **pulp_last_updated__lte** | **DateTime**| Filter results where pulp_last_updated is less than or equal to value | [optional] 
 **pulp_last_updated__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_last_updated is between two comma separated values | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedostreeOstreeRemoteResponseList**](PaginatedostreeOstreeRemoteResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(ostree_ostree_remote_href, patchedostree_ostree_remote)

Update an ostree remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RemotesOstreeApi.new
ostree_ostree_remote_href = 'ostree_ostree_remote_href_example' # String | 
patchedostree_ostree_remote = PulpOstreeClient::PatchedostreeOstreeRemote.new # PatchedostreeOstreeRemote | 

begin
  #Update an ostree remote
  result = api_instance.partial_update(ostree_ostree_remote_href, patchedostree_ostree_remote)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RemotesOstreeApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_remote_href** | **String**|  | 
 **patchedostree_ostree_remote** | [**PatchedostreeOstreeRemote**](PatchedostreeOstreeRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> OstreeOstreeRemoteResponse read(ostree_ostree_remote_href, opts)

Inspect an ostree remote

A ViewSet class for OSTree remote repositories.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RemotesOstreeApi.new
ostree_ostree_remote_href = 'ostree_ostree_remote_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an ostree remote
  result = api_instance.read(ostree_ostree_remote_href, opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RemotesOstreeApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_remote_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**OstreeOstreeRemoteResponse**](OstreeOstreeRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(ostree_ostree_remote_href, ostree_ostree_remote)

Update an ostree remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RemotesOstreeApi.new
ostree_ostree_remote_href = 'ostree_ostree_remote_href_example' # String | 
ostree_ostree_remote = PulpOstreeClient::OstreeOstreeRemote.new # OstreeOstreeRemote | 

begin
  #Update an ostree remote
  result = api_instance.update(ostree_ostree_remote_href, ostree_ostree_remote)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RemotesOstreeApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_remote_href** | **String**|  | 
 **ostree_ostree_remote** | [**OstreeOstreeRemote**](OstreeOstreeRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

